Crate oas3_gen_support

Crate oas3_gen_support 

Structs

EventStream
A stream of Server-Sent Events (SSE) that deserializes each event’s data as JSON.
Method
The Request Method (VERB)
PipeSeparator
Pipe separator for OpenAPI pipeDelimited style
TooManyRequests

Enums

DiagnosticsError
EventStreamError
RateLimit

Traits

Diagnostics

Type Aliases

StringWithCommaSeparator
De/Serialize a delimited collection using [Display] and [FromStr] implementation
StringWithPipeSeparator
De/Serialize a delimited collection using [Display] and [FromStr] implementation
StringWithSpaceSeparator
De/Serialize a delimited collection using [Display] and [FromStr] implementation

Attribute Macros

bon
Companion macro for builder. You should place it on top of the impl block where you want to define methods with the builder macro.

Derive Macros

Default
The main derive of this crate.